Flat UI - Free User Interface Kit

#
Flat UI Free User Interface Kit

# Basic elements

### Buttons

Primary Button
Warning Button
Default Button
Danger Button
Success Button
Inverse Button
Info Button
Disabled Button

### Menu

### Input

### Progress bars & Sliders

### Navigation

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8

### Checkboxes

Unchecked Checked Disabled unchecked Disabled checked

### Radio Buttons

Radio is off Radio is on Disabled radio is off Disabled radio is on

### Switches

### Tags

### Share

- Facebook
- Twitter
- Pinterest

Share

### Tooltips

### Typography

# Header 1Showers across the W

## Header 2Give this quartet a few

### Header 3The Vatican transitions to a

#### Header 4Great American Bites: Telluride's Oak, The

##### Header 5Author Diane Alberts loves her some good

###### Header 6With the success of young-adult book-to-movie

Paragraph

Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Donec ullamcorper nulla non metus auctor fringilla. Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit.

Image

Note: gravida at eget metus. Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit.

Lead Text

Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.

Quote

> Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Donec ullamcorper nulla non metus auctor fringilla. Duis mollis, est non commodo luctus.

> Steve Jobs, CEO Apple

Small Font

Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Donec ullamcorper nulla non metus auctor fringilla. Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit.

### Color Swatches

#1abc9c
  Turquoise

#16a085
  Green sea

#2ecc71
  Emerald

#27ae60
  Nephritis

#3498db
  Peter river

#2980b9
  Belize hole

#9b59b6
  Amethyst

#8e44ad
  Wisteria

#34495e
  Wet asphalt

#2c3e50
  Midnight blue

#f1c40f
  Sun flower

#f39c12
  Orange

#e67e22
  Carrot

#d35400
  Pumpkin

#e74c3c
  Alizarin

#c0392b
  Pomegranate

#ecf0f1
  Clouds

#bdc3c7
  Silver

#95a5a6
  Concrete

#7f8c8d
  Asbestos

###### SWATCHES

Colors — is almost the most important part of the Flat UI. Better to use different shades of provided colors than new.

For your convenience we also provide Swatches Preset (flat‑ui‑swatches.aco in the Pack folder).

No gradients, no shadows.

### Icons (14)

### Glyphs (30)

# Samples

- #### Meet Adrian at 6pm

  Times Square

- #### Chat with V.Kudinov

  Skype conference an 9 am

- #### Watch Iron Man

  1998 Broadway

- #### Fix bug on a Website

  As soon as possible

### Web Oriented

100% convertable to HTML/CSS layout.

Get Pro

### Easy to Customize

Vector-based shapes and minimum of layer styles.

Get Pro

### Color Swatches

Easy to add or change elements.

Get Pro

### Free for Share

Your likes, shares and comments helps us.

Get Pro

#### Welcome to Mail App

Login Lost your password?
Follow

##### @monstercritic

###### Tourist. Designer. NYC shmidt.in

Download

Your likes, shares and comments make us happy!